@@ -19,6 +19,7 @@ from .qestatistics import getPrevTradingDay
 from .qeglobal import getInstTraderQueue, getClassInstIDs
 from .qeinterface import simuqueue
 from qesdk import get_valid_instID
+from .qeglobal import g_dataSlide
 '''
 以下为需要订阅行情的合约号，注意选择有效合约；
 有效连上但没有行情可能是过期合约或者不再交易时间内导致
@@ -55,18 +56,20 @@ def getValidPrice(price):
 def timer_callback():
     global timer, mduserspi
     logger.debug('timer callback')
-        
     now = datetime.now()
-    if checkMarketTime(now):
-        if mduserspi and len(mduserspi.subID) > 0:
+    if checkMarketTime(now) :
+        '''if mduserspi and len(mduserspi.subID) > 0:
             subID = mduserspi.subID
-            mduserspi.SubscribeMarketData([id.encode('utf-8') for id in subID])
+            mduserspi.tapi.SubscribeMarketData([id.encode('utf-8') for id in subID],len(subID))
         else:
             print("No intrumentIDs be subscribed")
-    else:
-        timer = threading.Timer(30, timer_callback)
-        timer.start()
-    
+        '''
+        if mduserspi and not mduserspi.bFirstLogin and not mduserspi.connected:
+            mduserspi.login()    
+    timer = threading.Timer(30, timer_callback)
+    timer.start()
+        
+   
     
 def checkMarketTime(now):
     global g_mode_724
@@ -166,6 +169,7 @@ class CFtdcMdSpi(MdApiWrapper):
         self.instTime = {}
         self.tradingDay = ''
         self.stratInstances = {}
+        self.bFirstLogin = True
 
     def Init(self) -> None:
         """
@@ -203,6 +207,12 @@ class CFtdcMdSpi(MdApiWrapper):
     def OnFrontConnected(self) -> None:
         print(u"ctp行情服务器连接成功")
         logger.info (u"ctp行情服务器连接成功")
+        now = datetime.now()
+        if checkMarketTime(now):
+            self.login()
+        
+        
+    def login(self):    
         loginfield = ReqUserLoginField()
         loginfield.BrokerID=self.broker
         loginfield.UserID=self.user
@@ -237,9 +247,6 @@ class CFtdcMdSpi(MdApiWrapper):
             print(u"ctp行情服务器已经断开")
             logger.info(u"ctp行情服务器已经断开")
         self.connected = False    
-        if not timer is None and not timer.finished:
-            timer.cancel()
-            timer.join()
 
     def OnHeartBeatWarning(self, nTimeLapse) -> None:
         """
@@ -258,7 +265,8 @@ class CFtdcMdSpi(MdApiWrapper):
             logger.error (f"Market Data System Login, SessionID={pRspUserLogin.SessionID},ErrorID={pRspInfo.ErrorID},ErrorMsg={pRspInfo.ErrorMsg}")
             
         self.bReady = True
-        now = datetime.now()
+        self.bFirstLogin = False
+        #now = datetime.now()
         if pRspUserLogin.TradingDay != '':
             if self.tradingDay != pRspUserLogin.TradingDay:
                 if self.tradingDay != '':
@@ -266,13 +274,10 @@ class CFtdcMdSpi(MdApiWrapper):
                 self.tradingDay = pRspUserLogin.TradingDay
         elif self.tradingDay == '':
             self.tradingDay = getLocalTradingDay(now)
-        if checkMarketTime(now):
-            if len(self.subID) >0:
-                time.sleep(1)
-                self.SubscribeMarketData([id.encode('utf-8') for id in self.subID])
-        else:
-            timer = threading.Timer(30, timer_callback)
-            timer.start()
+        #if checkMarketTime(now):
+        if len(self.subID) >0:
+            time.sleep(1)
+            self.SubscribeMarketData([id.encode('utf-8') for id in self.subID])
 
     def OnRspUserLogout(self, pUserLogout, pRspInfo, nRequestID, bIsLast) -> None:
         """
@@ -351,9 +356,11 @@ class CFtdcMdSpi(MdApiWrapper):
         
         timedigit = int(actionDay)*1000000000 +(ctime+inc)
         timestr = (actionDay +' '+ pDepthMarketData.UpdateTime+'.'+str(pDepthMarketData.UpdateMillisec + 1000)[1:])
+        qeinst = transInstID2Context(instid, exID)
         mddata={'tradingday':self.tradingDay,\
         'time': timestr,\
         'timedigit': timedigit,\
+        'inst':qeinst,\
         'current': getValidPrice(pDepthMarketData.LastPrice),\
         'presett': getValidPrice(pDepthMarketData.PreSettlementPrice),\
         'preclose':getValidPrice(pDepthMarketData.PreClosePrice),\
@@ -374,7 +381,7 @@ class CFtdcMdSpi(MdApiWrapper):
         d = {}
         d['type'] = qetype.KEY_MARKET_DATA
 #         d['time'] = timedigit
-        d['instid'] = transInstID2Context(instid, exID)
+        d['instid'] = qeinst
         d['data'] = mddata
         #print(d)
         self.callback(d)
@@ -400,6 +407,7 @@ class CFtdcMdSpi(MdApiWrapper):
             if d['type'] == qetype.KEY_MARKET_DATA:
                 datastr = json.dumps(d['data'])
                 cd = copy.copy(d)
+                g_dataSlide.update([d])
                 if self.strats['async'] and self.recmode:
                     self.strats['queue'].put(cd)
                 elif self.stratInsts:
@@ -600,7 +608,7 @@ class CFtdcMdSpi(MdApiWrapper):
         pass
 
 def runQEMarketProcess(user, passwd, strats,runmode, setting_dict, mode_724=False):
-    global mduserspi, g_mode_724
+    global mduserspi, g_mode_724, timer
     evalmode = False
     if setting_dict is not None and setting_dict['api'] == 'ctptest':
         evalmode = True
@@ -626,7 +634,9 @@ def runQEMarketProcess(user, passwd, strats,runmode, setting_dict, mode_724=Fals
     g_mode_724 = mode_724
 
     pass_flag = True
-
+    timer = threading.Timer(30, timer_callback)
+    timer.start()
+    
     if setting_dict is not None:
         mduserspi.initCallback( setting_dict['investorid'],setting_dict['password'])
         mduserspi.broker = bytes(setting_dict['brokerid'],'utf-8')
