@@ -6,12 +6,13 @@ Created on Wed Mar 30 15:24:34 2022
 """
 import threading
 from multiprocessing import Queue
-from qesdk import  get_instrument_setting
+from qesdk import  get_instrument_setting, get_risk_control_parameter
 import platform
 from datetime import datetime 
 import chinese_calendar
+import collections
 
-dbconfig = {'ip': '103.36.172.183','port': 58888, 'local':'127.0.0.1'};
+dbconfig = {'ip': 'data.quantease.store','port': 58888, 'local':'127.0.0.1'};
 try:
     from .qedbconfig import dbconfig_outside
     dbconfig = {**dbconfig, **dbconfig_outside}
@@ -19,6 +20,28 @@ except:
     pass
 
 
+class qeDataSlide(collections.UserDict):
+    def __missing__(self, key):
+        key = str(key)
+        if not key in self.data:
+            return {"current":0,"presett":0,"preclose":0}    
+        return self.data[key]
+ 
+    def __contains__(self, key):
+        return str(key) in self.data
+ 
+    def __setitem__(self, key, item):
+        self.data[str(key)] = item
+    
+    def __getitem__(self, key):
+        key = str(key)
+        if not key in self.data:
+            return {"current":0,"presett":0,"preclose":0}    
+        return self.data[key]
+    def update(self, datalist):
+        for data in datalist:
+            self.data[data['instid']] = data["data"]
+g_dataSlide = qeDataSlide()
 
 
 mutex = threading.Lock()
@@ -224,6 +247,14 @@ def getInstrumentSetting(instid):
     else:
         return get_instrument_setting(instid, False)
     
-    
+
+def get_riskctl_paras():
+    return get_risk_control_parameter()
+
 def getPlatform():
-    return platform.system().lower()
\ No newline at end of file
+    return platform.system().lower()
+
+
+
+        
+    #print('dataSlide',dataSlide)    
\ No newline at end of file
