@@ -14,7 +14,7 @@ import pickle
 import zlib
 from .qeglobal import getExemode, dbconfig
 
-remote_db = {'ip':'103.36.172.183', 'port': 9019}
+remote_db = {'ip':'data.quantease.store', 'port': 9019}
 local_db = {'ip':'192.168.123.188', 'port':58002}
 
 dbip =  remote_db['ip'] if dbconfig['ip'] == remote_db['ip'] else local_db['ip']
@@ -738,6 +738,36 @@ def getDBHedgeMarketDatareal(userid, stratName, instid_hedge, fromtime):
 def getDBHedgeMarketDatareal1(userid, stratName, instid_hedge, fromtime,start=0,num=15000,endtime=302112021015560000):
     return myredis.zrangebyscore('sysgen_realDB1_' + str(userid) + '_' + str(stratName) + '_' + instid_hedge,
                                  fromtime, endtime,start=start,num=num, withscores=True)
+
+############################UNIFORM SAVE/LOAD#####################################
+@check_myredis
+def saveUnfinishedOrders(user, token, tradingday, orders):
+    data = json.dumps(orders)
+    myredis.hset('sysgen_pendorders_'+user+'_'+token, tradingday, data)
+
+
+@check_myredis
+def loadUnfinishedOrders(user, token, tradingday):
+    ret = myredis.hget('sysgen_pendorders_'+user+'_'+token, tradingday)
+    if ret:
+        return json.loads(ret)
+
+@check_myredis
+def saveRiskCtlRecord(user, token, tradingDay, record, runmode='real'):
+    data = json.dumps(record)
+    key = 'sysgen_riskctl_'+user+'_'+token if runmode == 'real' else 'sysgen_riskctl_simu_'+user+'_'+token
+    myredis.hset(key, tradingDay, data)
+
+@check_myredis
+def loadRiskCtlRecord(user, token, tradingDay, runmode='real'):
+    key = 'sysgen_riskctl_'+user+'_'+token if runmode == 'real' else 'sysgen_riskctl_simu_'+user+'_'+token
+    ret = myredis.hget(key, tradingDay)
+    if ret:
+        return json.loads(ret)
+        
+    
+    
+
     
 ######################################################################
 ##    Redis commands
